use 5.014;

use strict;
use warnings;

use Test::More;

=name

Data::Object::Autobox::Number

=abstract

Data-Object Autoboxing for Number Objects

=synopsis

  use Data::Object::Autobox::Number;

=description

This package implements autoboxing via L<Data::Object::Autobox> for
L<Data::Object::Number> objects.

=cut

use_ok "Data::Object::Autobox::Number";

ok 1 and done_testing;
