use strict;
use warnings;
use Test::More;

use_ok 'Data::Object::Func::Number';
use_ok 'Data::Object::Func::Number::Abs';
use_ok 'Data::Object::Func::Number::Atan2';
use_ok 'Data::Object::Func::Number::Cos';
use_ok 'Data::Object::Func::Number::Decr';
use_ok 'Data::Object::Func::Number::Defined';
use_ok 'Data::Object::Func::Number::Exp';
use_ok 'Data::Object::Func::Number::Hex';
use_ok 'Data::Object::Func::Number::Incr';
use_ok 'Data::Object::Func::Number::Int';
use_ok 'Data::Object::Func::Number::Log';
use_ok 'Data::Object::Func::Number::Mod';
use_ok 'Data::Object::Func::Number::Neg';
use_ok 'Data::Object::Func::Number::Pow';
use_ok 'Data::Object::Func::Number::Sin';
use_ok 'Data::Object::Func::Number::Sqrt';

ok 1 and done_testing;
