use strict;
use warnings;
use Test::More;

use_ok 'Data::Object::Func::Any';
use_ok 'Data::Object::Func::Any::Defined';
use_ok 'Data::Object::Func::Any::Eq';
use_ok 'Data::Object::Func::Any::Gt';
use_ok 'Data::Object::Func::Any::Ge';
use_ok 'Data::Object::Func::Any::Lt';
use_ok 'Data::Object::Func::Any::Le';
use_ok 'Data::Object::Func::Any::Ne';

ok 1 and done_testing;
