use strict;
use warnings;
use Test::More;

use_ok 'Data::Object::Func::Array';
use_ok 'Data::Object::Func::Array::All';
use_ok 'Data::Object::Func::Array::Any';
use_ok 'Data::Object::Func::Array::Clear';
use_ok 'Data::Object::Func::Array::Count';
use_ok 'Data::Object::Func::Array::Defined';
use_ok 'Data::Object::Func::Array::Delete';
use_ok 'Data::Object::Func::Array::Each';
use_ok 'Data::Object::Func::Array::EachKey';
use_ok 'Data::Object::Func::Array::EachNValues';
use_ok 'Data::Object::Func::Array::EachValue';
use_ok 'Data::Object::Func::Array::Empty';
use_ok 'Data::Object::Func::Array::Eq';
use_ok 'Data::Object::Func::Array::Exists';
use_ok 'Data::Object::Func::Array::First';
use_ok 'Data::Object::Func::Array::Ge';
use_ok 'Data::Object::Func::Array::Get';
use_ok 'Data::Object::Func::Array::Grep';
use_ok 'Data::Object::Func::Array::Gt';
use_ok 'Data::Object::Func::Array::Hash';
use_ok 'Data::Object::Func::Array::Hashify';
use_ok 'Data::Object::Func::Array::Head';
use_ok 'Data::Object::Func::Array::Invert';
use_ok 'Data::Object::Func::Array::Iterator';
use_ok 'Data::Object::Func::Array::Join';
use_ok 'Data::Object::Func::Array::Keyed';
use_ok 'Data::Object::Func::Array::Keys';
use_ok 'Data::Object::Func::Array::Last';
use_ok 'Data::Object::Func::Array::Le';
use_ok 'Data::Object::Func::Array::Length';
use_ok 'Data::Object::Func::Array::List';
use_ok 'Data::Object::Func::Array::Lt';
use_ok 'Data::Object::Func::Array::Map';
use_ok 'Data::Object::Func::Array::Max';
use_ok 'Data::Object::Func::Array::Min';
use_ok 'Data::Object::Func::Array::Ne';
use_ok 'Data::Object::Func::Array::None';
use_ok 'Data::Object::Func::Array::Nsort';
use_ok 'Data::Object::Func::Array::One';
use_ok 'Data::Object::Func::Array::Pairs';
use_ok 'Data::Object::Func::Array::PairsArray';
use_ok 'Data::Object::Func::Array::PairsHash';
use_ok 'Data::Object::Func::Array::Part';
use_ok 'Data::Object::Func::Array::Pop';
use_ok 'Data::Object::Func::Array::Push';
use_ok 'Data::Object::Func::Array::Random';
use_ok 'Data::Object::Func::Array::Reverse';
use_ok 'Data::Object::Func::Array::Rnsort';
use_ok 'Data::Object::Func::Array::Rotate';
use_ok 'Data::Object::Func::Array::Rsort';
use_ok 'Data::Object::Func::Array::Set';
use_ok 'Data::Object::Func::Array::Shift';
use_ok 'Data::Object::Func::Array::Size';
use_ok 'Data::Object::Func::Array::Slice';
use_ok 'Data::Object::Func::Array::Sort';
use_ok 'Data::Object::Func::Array::Sum';
use_ok 'Data::Object::Func::Array::Tail';
use_ok 'Data::Object::Func::Array::Unique';
use_ok 'Data::Object::Func::Array::Unshift';
use_ok 'Data::Object::Func::Array::Values';

ok 1 and done_testing;
